Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(433)

Unified Diff: remoting/host/mouse_clamping_filter.h

Issue 850983002: Implement video frame acknowledgements in the chromoting protocol. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/mouse_clamping_filter.h
diff --git a/remoting/host/mouse_clamping_filter.h b/remoting/host/mouse_clamping_filter.h
index 994abbe28a4776b122921b27a0e648a6cf90c36b..12656238b39f4064db059d0cf0805df38c15eaa1 100644
--- a/remoting/host/mouse_clamping_filter.h
+++ b/remoting/host/mouse_clamping_filter.h
@@ -7,33 +7,34 @@
#include "base/compiler_specific.h"
#include "remoting/protocol/mouse_input_filter.h"
-#include "remoting/protocol/video_stub.h"
+#include "remoting/protocol/video_sender.h"
namespace remoting {
// Filtering VideoStub implementation which configures a MouseInputFilter to
// clamp mouse events to fall within the dimensions of the most-recently
// received video frame.
-class MouseClampingFilter : public protocol::VideoStub {
+class MouseClampingFilter : public protocol::VideoSender {
public:
explicit MouseClampingFilter(protocol::InputStub* input_stub);
~MouseClampingFilter() override;
protocol::InputStub* input_filter() { return &input_filter_; }
- void set_video_stub(protocol::VideoStub* video_stub) {
- video_stub_ = video_stub;
+ void set_video_sender(protocol::VideoSender* video_sender) {
+ video_sender_ = video_sender;
}
- // protocol::VideoStub implementation.
+ // protocol::VideoSender implementation.
void ProcessVideoPacket(scoped_ptr<VideoPacket> video_packet,
const base::Closure& done) override;
+ bool SupportsAcks() override;
private:
// Clamps mouse event coordinates to the video dimensions.
protocol::MouseInputFilter input_filter_;
- protocol::VideoStub* video_stub_;
+ protocol::VideoSender* video_sender_;
DISALLOW_COPY_AND_ASSIGN(MouseClampingFilter);
};
@@ -7,33 +7,34 @@
namespace remoting {
-// Filtering VideoStub implementation which configures a MouseInputFilter to
+// Filtering VideoSender implementation which configures a MouseInputFilter to
// clamp mouse events to fall within the dimensions of the most-recently
// received video frame.

Powered by Google App Engine
This is Rietveld 408576698